pub enum DecodeError {
NotAPointer(NotAPointerReason),
Malformed(MalformedReason),
}Variants
NotAPointer(NotAPointerReason)
The input does not look like a pointer at all.
Malformed(MalformedReason)
The input has pointer shape but is invalid.
Implementations
Sourceimpl DecodeError
impl DecodeError
Sourcepub fn is_not_a_pointer(&self) -> bool
pub fn is_not_a_pointer(&self) -> bool
true if the input doesn’t look like a pointer; the smudge filter
should pass the bytes through unchanged in this case.